@@ -4,7 +4,8 @@ Root url's map for application
 """
 from django.conf.urls.defaults import *
 
-from sveedocuments.views.page import HelpPageView, PageIndexView, PageDetailsView, PageSourceView
+from sveedocuments.views.page import (HelpPageView, PageIndexView, PageDetailsView, 
+                                        PageSourceView, PagePDFView)
 
 urlpatterns = patterns('',
     url(r'^$', PageIndexView.as_view(), name='documents-index'),
@@ -17,3 +18,8 @@ urlpatterns = patterns('',
     url(r'^(?P<slug>[-\w]+)/$', PageDetailsView.as_view(), name='documents-page-details'),
     url(r'^(?P<slug>[-\w]+)/source/$', PageSourceView.as_view(), name='documents-page-source'),
 )
+
+if not getattr(PagePDFView, 'is_dummy', False):
+    urlpatterns += patterns('',
+        url(r'^(?P<slug>[-\w]+)/pdf/$', PagePDFView.as_view(), name='documents-page-pdf'),
+    )
